@@ -3,8 +3,9 @@
     http://nedbatchelder.com/blog/200803/python_code_complexity_microtool.html
     MIT License.
 """
-
-import compiler, optparse, sys
+import compiler
+import optparse
+import sys
 
 
 class PathNode:
@@ -13,7 +14,8 @@ class PathNode:
         self.look = look
 
     def to_dot(self):
-        print 'node [shape=%s,label="%s"] %d;' % (self.look, self.name, self.dot_id())
+        print 'node [shape=%s,label="%s"] %d;' % \
+                (self.look, self.name, self.dot_id())
 
     def dot_id(self):
         return id(self)
@@ -172,7 +174,12 @@ class PathGraphingAstVisitor(compiler.visitor.ASTVisitor):
 
 def get_code_complexity(code, min=7, filename='stdin'):
     complex = []
-    ast = compiler.parse(code)
+    try:
+        ast = compiler.parse(code)
+    except AttributeError as e:
+        print >> sys.stderr, "Unable to parse %s: %s" % (filename, e)
+        return 0
+
     visitor = PathGraphingAstVisitor()
     visitor.preorder(ast, visitor)
     for graph in visitor.graphs.values():
@@ -199,12 +206,15 @@ def get_module_complexity(module_path, min=7):
 
 def main(argv):
     opar = optparse.OptionParser()
-    opar.add_option("-d", "--dot", dest="dot", help="output a graphviz dot file", action="store_true")
-    opar.add_option("-m", "--min", dest="min", help="minimum complexity for output", type="int", default=2)
+    opar.add_option("-d", "--dot", dest="dot",
+                    help="output a graphviz dot file", action="store_true")
+    opar.add_option("-m", "--min", dest="min",
+                    help="minimum complexity for output", type="int",
+                    default=2)
 
     options, args = opar.parse_args(argv)
 
-    text = open(args[0], "rU").read()+'\n\n'
+    text = open(args[0], "rU").read() + '\n\n'
     ast = compiler.parse(text)
     visitor = PathGraphingAstVisitor()
     visitor.preorder(ast, visitor)
